PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Enums.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
Enums.hpp
1#ifndef GYM_PCB_ENUMS_H
2#define GYM_PCB_ENUMS_H
3
4enum SignalType
5{
6 USER = 0x0,
7 SIGNAL = 0x1,
8 POWER = 0x2,
9 GROUND = 0x4,
10 SIGNAL_POWER = 0x3,
11 SIGNAL_GROUND = 0x5,
12 POWER_GROUND = 0x6,
13 ANY = 0x7
14};
15SignalType signalType(const std::string_view);
16
17std::string to_string(SignalType);
18
19#endif // GYM_PCB_ENUMS_H